==> npm-package-json-lint-config-2.2.0.tgz: package/README.md <==
# FabLab npm-package-json-lint Configuration

The [npm-package-json-lint](https://npmpackagejsonlint.org/) configuration for FabLab projects.

## Usage

### Installation

Install the package from [npm](https://www.npmjs.com/)
(requires [Node.js](https://nodejs.org/)):

```sh
npm install --save-dev @fablab/npm-package-json-lint-config
```

Install peer dependencies:

```sh
npm install --save-dev npm-package-json-lint npm-package-json-lint-config-default
```

### Configuration

Configure npm-package-json-lint to use the configuration by editing `npmpackagejsonlint.config.js`:

```js
module.exports = {
	'extends': '@fablab/npm-package-json-lint-config',
};
```

## Development

### Documentation

Generate documentation into the `doc` directory with [JSDoc](https://jsdoc.app/):

```sh
npm run doc
```

### Linting

Lint the project with [ESLint](https://eslint.org/) and [npm-package-json-lint](https://npmpackagejsonlint.org/):

```sh
npm run lint
```

### Testing

Test the configuration by linting itself with [npm-package-json-lint](https://npmpackagejsonlint.org/):

```sh
npm run test
```

### Dependencies

Check for new dependencies with [npm-check](https://github.com/dylang/npm-check):

```sh
npm run npm-check
```

### Release

Publish a release with [np](https://github.com/sindresorhus/np):

```sh
npm run release
```

## Legal Information

### Copyright

Copyright © 2018, 2019, 2020  Anthony Di Pietro

### License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see
[http://www.gnu.org/licenses/](http://www.gnu.org/licenses/).

==> npm-package-json-lint-config-4.0.0.tgz: package/README.md <==
# FabLab npm-package-json-lint Configuration

The [npm-package-json-lint](https://npmpackagejsonlint.org/) configuration for FabLab projects.

**This package is deprecated. Use `@adp-psych/npm-package-json-lint-config` instead.**

## Usage

### Installation

Install the package from [npm](https://www.npmjs.com/)
(requires [Node.js](https://nodejs.org/)):

```sh
npm install --save-dev @fablab/npm-package-json-lint-config
```

Install peer dependencies:

```sh
npm install --save-dev npm-package-json-lint npm-package-json-lint-config-default @adp-psych/npm-package-json-lint-config
```

### Configuration

Configure npm-package-json-lint to use the configuration by editing `npmpackagejsonlint.config.js`:

```js
module.exports = {
	'extends': '@fablab/npm-package-json-lint-config',
};
```

## Legal Information

### Copyright

Copyright © 2018, 2019, 2020  Anthony Di Pietro

### License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see
[http://www.gnu.org/licenses/](http://www.gnu.org/licenses/).
